==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-ssm/source/model/DescribeInstancePatchStatesForPatchGroupResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/ssm/model/DescribeInstancePatchStatesForPatchGroupResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::SSM::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

DescribeInstancePatchStatesForPatchGroupResult::DescribeInstancePatchStatesForPatchGroupResult()
{
}

DescribeInstancePatchStatesForPatchGroupResult::DescribeInstancePatchStatesForPatchGroupResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

DescribeInstancePatchStatesForPatchGroupResult& DescribeInstancePatchStatesForPatchGroupResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("InstancePatchStates"))
  {
    Array<JsonView> instancePatchStatesJsonList = jsonValue.GetArray("InstancePatchStates");
    for(unsigned instancePatchStatesIndex = 0; instancePatchStatesIndex < instancePatchStatesJsonList.GetLength(); ++instancePatchStatesIndex)
    {
      m_instancePatchStates.push_back(instancePatchStatesJsonList[instancePatchStatesIndex].AsObject());
    }
  }

  if(jsonValue.ValueExists("NextToken"))
  {
    m_nextToken = jsonValue.GetString("NextToken");

  }



  return *this;
}

==> mingw-w64-aws-sdk-cpp-1.10.41-1.src.tar.zst: aws-sdk-cpp-1.10.41/aws-cpp-sdk-ssm/source/model/DescribeInstancePatchStatesForPatchGroupResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/ssm/model/DescribeInstancePatchStatesForPatchGroupResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::SSM::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

DescribeInstancePatchStatesForPatchGroupResult::DescribeInstancePatchStatesForPatchGroupResult()
{
}

DescribeInstancePatchStatesForPatchGroupResult::DescribeInstancePatchStatesForPatchGroupResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

DescribeInstancePatchStatesForPatchGroupResult& DescribeInstancePatchStatesForPatchGroupResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("InstancePatchStates"))
  {
    Aws::Utils::Array<JsonView> instancePatchStatesJsonList = jsonValue.GetArray("InstancePatchStates");
    for(unsigned instancePatchStatesIndex = 0; instancePatchStatesIndex < instancePatchStatesJsonList.GetLength(); ++instancePatchStatesIndex)
    {
      m_instancePatchStates.push_back(instancePatchStatesJsonList[instancePatchStatesIndex].AsObject());
    }
  }

  if(jsonValue.ValueExists("NextToken"))
  {
    m_nextToken = jsonValue.GetString("NextToken");

  }



  return *this;
}
